#
# spec file for package opensc
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           opensc
Version:        0.18.0
Release:        lp150.2.6.1
Summary:        Smart Card Utilities
License:        LGPL-2.1-or-later
Group:          Productivity/Security
Url:            https://github.com/OpenSC/OpenSC/wiki
Source:         https://github.com/OpenSC/OpenSC/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
Source2:        %{name}-rpmlintrc
# Register with p11-kit
# https://web.archive.org/web/20111225073733/http://www.opensc-project.org/opensc/ticket/390
Source3:        opensc.module
# PATCH-FIX-UPSTREAM opensc-desktop.patch https://github.com/OpenSC/OpenSC/issues/1402 sbrabec@suse.com -- Fix desktop file.
Patch1:         opensc-desktop.patch
# PATCH-FIX-UPSTREAM opensc-bash-completions.patch sbrabec@suse.com https://github.com/OpenSC/OpenSC/issues/1403 -- Use correct bash-completion path.
Patch2:         opensc-bash-completions.patch
# PATCH-FEATURE-OPENSUSE opensc-desktop2.patch https://github.com/OpenSC/OpenSC/issues/1402 sbrabec@suse.com -- Add GenericName to the desktop file.
Patch3:         opensc-desktop2.patch
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  libtool
BuildRequires:  libxslt
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
BuildRequires:  pkgconfig(bash-completion)
BuildRequires:  pkgconfig(libpcsclite)
BuildRequires:  pkgconfig(openssl)
Requires:       pcsc-lite
# There is no more devel package.
Obsoletes:      opensc-devel < %{version}
%define completionsdir %(pkg-config --variable completionsdir bash-completion)

%description
OpenSC provides a set of utilities to access smart cards. It mainly
focuses on cards that support cryptographic operations. It facilitates
their use in security applications such as mail encryption,
authentication, and digital signature. OpenSC implements the PKCS#11
API. Applications supporting this API, such as Mozilla Firefox and
Thunderbird, can use it. OpenSC implements the PKCS#15 standard and aims
to be compatible with every software that does so, too.

Before purchasing any cards, please read carefully documentation on the
web pageonly some cards are supported. Not only card type matters, but
also card version, card OS version and preloaded applet. Only subset of
possible operations may be supported for your card. Card initialization
may require third party proprietary software.

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1

%build
autoreconf -fvi
%configure \
  --docdir=%{_docdir}/%{name} \
  --disable-static \
  --enable-doc \
  --disable-silent-rules
make %{?_smp_mflags}

%install
%make_install
cp COPYING NEWS README %{buildroot}%{_docdir}/%{name}
# Private library.
rm %{buildroot}%{_libdir}/libopensc.so
install -D -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/pkcs11/modules/opensc.module

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%doc %dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/COPYING
%doc %{_docdir}/%{name}/NEWS
%doc %{_docdir}/%{name}/README
%doc %{_docdir}/%{name}/tools.html
%{_bindir}/*
%{_datadir}/applications/*.desktop
%{_datadir}/opensc
# Note: .la and .so must be in the main package, required by ltdl:
%{_libdir}/*.la
%{_libdir}/*.so*
%dir %{_libdir}/pkcs11
%{_libdir}/pkcs11/*.so
%{_libdir}/pkgconfig/opensc-pkcs11.pc
%{_mandir}/man?/*%{ext_man}
%config %{_sysconfdir}/opensc.conf
%dir %{_sysconfdir}/pkcs11
%config %{_sysconfdir}/pkcs11/modules/
# This is a private library. There is no reason to split it to libopensc* package.
%{_libdir}/libopensc.so.*
%{completionsdir}/*

%changelog
* Tue Jul 10 2018 sbrabec@suse.com
- Update to version 0.18.0:
  * Further improvements of PIN support.
  * Large number of improvements and fixes
    (boo#1097951, boo#1100501).
  * See /usr/share/doc/packages/opensc/NEWS for complete list.
- Add opensc-desktop.patch, opensc-desktop2.patch and
  opensc-bash-completions.patch.
* Mon Jan  1 2018 michael@stroeder.com
- update to version 0.17.0:
  * support for new cards
  * PIN support enhancemets
  * added .pc file
  * builds with OpenSSL 1.1.0 (1074799)
  * See /usr/share/doc/packages/opensc/NEWS for complete list.
* Tue Jul 18 2017 tchvatal@suse.com
- Switch to tarball fetching from github
- Few small cleanups
* Tue Nov 22 2016 sbrabec@suse.com
- Add baselibs.conf to provide 32-bit PKCS11 plugins (bsc#996047).
- Drop opensc-ADVISORIES. There is no new advisory since 2009.
* Tue Jul  5 2016 t.gruner@katodev.de
- update to version 0.16.0
- remove fix (issue 505)
- clean up spec-file
* Thu Jul 30 2015 bwachter-pkg@lart.info
- update to version 0.15.0
- register with p11-kit
  (https://www.opensc-project.org/opensc/ticket/390)
* Mon Feb 16 2015 michael@stroeder.com
- update to version 0.14.0
* Tue Dec  3 2013 luizluca@tre-sc.gov.br
- update to version 0.13.0
* Tue Jun 12 2012 mgorse@suse.com
- make needed directories before running make install
* Thu Sep 29 2011 lmedinas@opensuse.org
- Updated to version 0.12.2:
  * Builds are now silent by default when OpenSC is built from
    source on Unix.
  * Using --wait with command line tools works with 64bit Linux
    again.
  * Greatly improved OpenPGP card support, including OpenPGP
    2.0 cards like the one found in German Privacy Foundation
    CryptoStick.
  * Fixed support for FINeID cards issued after 01.03.2011 with
    2048bit keys.
  * #256: Fixed support for TCOS cards (broken since 0.12.0).
  * Added support for IDKey-cards to TCOS3 driver.
  * #361: Improved PC/SC driver to fetch the maximum PIN sizes
    from the open source CCID driver. This fixes the issue for
    Linux/OSX with recent driver.
  * Fix FINeID cards for organizations.
  * Several smaller bugs and compiler warnings fixed
- Updated to version 0.12.1:
  * IAS-ECC 1.0.1
  * Support for cards with multiple PKCS#15 applications
  * New card driver: IAS/ECC 1.0.1
  * rutoken-tool has been deprecated and removed.
  * eidenv and piv-tool utilities now have manual pages.
  * pkcs11-tool now requires the use of --module parameter.
  * All tools can now use an ATR as an argument to --reader,
    to skip to the card with given ATR.
  * opensc-tool -l with -v now shows information about the
    inserted cards.
  * Creating files have an enforced upper size limit, 64K
  * Support for multiple PKCS#15 applications with different
    AID-s. PKCS#15 applications can be listed with pkcs15-tool
  - -list-applications. Binding to a specific AID with PKCS#15
    tools can be done with --aid.
  * Hex strings (like card ATR or APDU-s) can now be separated
    by space, in addition to colons.
  * Pinpad readers known to be bogus are now ignored by OpenSC.
    At the moment only "HP USB Smart Card Keyboard" is disabled.
  * Numerous compiler warnings, unused code and internal bugs
    have been eliminated.
* Fri Jan  7 2011 sbrabec@suse.cz
- Updated to version 0.12.0:
  * Security fix (bnc#660109, CVE-2010-4523).
  * Only one backend is supported. openSUSE will use pcsc-lite.
  * libopensc made private, library should not be used by other
    applications. Please use generic PKCS#11 interface instead.
  * Signer plugin discontinued. Please use openssl engine_pkcs11.
  * No more depends on libassuan.
  * New card drivers.
  * Support for CardOS enhanced.
  * More changes and enhancements.
- libopensc merged back to the main package, as it is private now.
* Mon Aug 23 2010 sbrabec@suse.cz
- Fixed broken opensc-fix-gcc-warnings.patch (bnc#627619).
- Simplified plugin installation.
* Tue Apr 13 2010 puzel@novell.com
- update to version 0.11.13
  * Modify Rutoken S binary interfaces by Aktiv Co.
  * Muscle driver fixed (acl reading issue)
  * Many small fixes (e.g. mem leaks)
  * Compiling with openssl 1.0.0-beta fixed
  * Document integer problem in OpenSC and implement workaround
  * Improve entersafe profile to support private data objects
- Require pinentry
- add opensc-libassuan-2.patch
- add opensc-fix-gcc-warnings.patch
* Fri Jan  1 2010 jengelh@medozas.de
- package baselibs.conf
* Wed Aug  5 2009 sbrabec@suse.cz
- Updated to version 0.11.9:
  * New rutoken_ecp driver
  * Allow more keys/certificates/files etc. with entersafe tokens
  * Updates pkcs11.h from scute fixing warnings
  * Small fixes in rutoken driver
  * Major update for piv driver with increased compatibility
* Thu Jul 30 2009 sbrabec@suse.cz
- libopensc2 should not require opensc (bnc#466430).
* Thu May  7 2009 sbrabec@suse.cz
- Updated to version 0.11.8:
  * Fix security problem in pkcs11-tool gen_keypair
    (PublicExponent 1) (bnc#501726)
    See http://en.opensuse.org/Smart_Cards/Advisories for more.
  * updated and improve entersafe driver. FTCOS/PK-01C cards are
    supported now, compatible with cards writen by Feitian's
    software on windows.
* Thu Apr  9 2009 sbrabec@suse.cz
- Fixed undefined code (bnc#440853).
- Don't call autoreconf on older products.
* Tue Mar 17 2009 sbrabec@suse.cz
- Updated to version 0.11.7:
  * hide_empty_slots now on by default? small logic change?
  * ruToken driver was updated.
  * openct virtual readers reduced to 2 by default.
  * Security issue: Fix private data support. (bnc#480262,
    CVE-2009-0368)
    See http://en.opensuse.org/Smart_Cards/Advisories for more.
  * Enable lock_login by default.
  * Disable allow_soft_keygen by default.
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Wed Sep 10 2008 sbrabec@suse.cz
- Updated to version 0.11.6:
  * New support for Feitian ePass3000.
  * GemSafeV1 improved to handle key_ref other than 3.
  * Build system rewritten.
  * ruToken now supported.
  * Allow specifying application name for data objects.
  * Basic reader hotplug support.
  * PC/SC library is dynamically linked.
  * PKCS#11 provider is now installed at LIBDIR/pkcs11.
  * PKCS#11 - Number of virtual slots moved into configuration.
  * PKCS#11 - Fix fork() compliance.
  * make sign_with_decrypt hack configureable for siemens cards.
* Mon Sep  1 2008 sbrabec@suse.cz
- Check validity of SSL certificates for all Siemens CardOS M4
  cards (SCA and SCB are affected as well, bnc#413496#c6).
* Thu Jul 31 2008 sbrabec@suse.cz
- Fixed initialization access rights for Siemens CardOS M4, added
  a security check to pkcs15-tool (bnc#413496, CVE-2008-2235)
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Feb  7 2008 sbrabec@suse.cz
- Updated to version 0.11.4:
  * Browser plugin support
  * Support Siemens CardOS initialized cards (signing with
    decryption)
  * Add Siemens CardOS M4.2B support (experimental)
  * Support for AKIS cards added (partial)
* Thu Jul 26 2007 sbrabec@suse.cz
- Updated to version 0.11.3:
  * make lots of internal functions and variables static.
  * fix 0 vs NULL in many places. fix ansi c style (void).
  * avoid variable names used also as glibc function (random etc.).
  * new code for deleting objects.
  * special hack for firefox.
  * suport for Athena APCOS cards added.
  * piv driver now supports bigger rsa keys too.
  * enabled pin caching by default.
  * use max_send_size 255 / max_recv_size 256 bytes by default.
  * increase pin buffer size to allow longer pin codes.
  * Added --read-ssk-key option to pkcs15-tool
  * use pkg-config for finding openct
  * use strlcpy function
  * use new pkcs11.h from scute with an open source license
  * add support for sha2 to pkcs15-crypt
  * add piv-tool for managing piv cards
  * add muscle driver
  * improved oberthur driver
  * add support for pcsc v2 part10
  * convert source files to utf-8
- Split package according to shared library packaging policy.
* Tue Feb 27 2007 mvaner@suse.cz
- Fixing dodgy use of sizeof (#238660)
  - sizeof.patch
* Mon Oct  2 2006 sbrabec@suse.cz
- Updated to version 0.11.1:
  * Update for piv pkcs#15 emulation
  * Improved TCOS driver for Uni Giesen Card
  * Handle size_t printf with "%%lu" and (unsigned long) cast
  * Add support for d-trust cards / improve micardo 2.1 driver
* Thu May 25 2006 sbrabec@suse.cz
- Fixed build for old SuSE Linux versions.
* Thu May 11 2006 sbrabec@suse.cz
- Fixed devel dependencies.
* Wed May 10 2006 sbrabec@suse.cz
- Updated to version 0.11.0.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan  5 2006 ro@suse.de
- added unpackaged so-links to devel filelist
* Tue Oct 25 2005 rhafer@suse.de
- added LDAP_DEPRECATED to CFLAGS to build correctly with·
  OpenLDAP 2.3
* Fri Sep  2 2005 okir@suse.de
- Removed +x permissions on opensc.conf (#114849)
* Thu Jul 14 2005 okir@suse.de
- Updated to latest upstream version
- Added missing documentation files (#75425)
* Fri Mar  4 2005 meissner@suse.de
- fixed gcc4 compilation.
* Fri Jan 21 2005 okir@suse.de
- Updated to latest upstream version (0.9.4)
* Thu Nov 18 2004 ro@suse.de
- use kerberos-devel-packages
* Mon Jul 19 2004 adrian@suse.de
- fix file list
* Mon Jul 12 2004 adrian@suse.de
- update to version 0.8.1
* Fri Mar 19 2004 okir@suse.de
- Fixed permissions and path names of some include files (#36432)
* Fri Jan 16 2004 kukuk@suse.de
- Add pam-devel to neededforbuild
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig and %%defattr
* Mon Aug  4 2003 okir@suse.de
- Build fixes for x86_64/ppc64
- use a version string other than "CVS" (#28423)
* Fri Aug  1 2003 okir@suse.de
- Updated to most recent upstream snapshot
* Thu Jun 12 2003 kukuk@suse.de
- Fix filelist and permissions
* Wed Jun  4 2003 ro@suse.de
- added rest of static libs to devel filelist
- remove unpackaged files from buildroot
* Wed Jan 15 2003 ro@suse.de
- use sasl2
* Thu Dec  5 2002 okir@suse.de
- fixed x86_64 build problem
- updated to latest upstream
* Fri Nov 29 2002 okir@suse.de
- updated to current CVS snapshot
* Fri Aug  9 2002 okir@suse.de
- added missing libs to files list
* Thu Jul  4 2002 ro@suse.de
- added heimdal-devel to neededforbuild to make libtool happy
* Fri Jun 28 2002 schwab@suse.de
- Fix bootstrap script.
- Use correct libtool macros.
* Mon May 27 2002 sf@suse.de
-  @libdir@ added to Makefile.am to use correct dirs for
  * /lib */lib64
* Tue Apr 30 2002 okir@suse.de
- Initial check-in
